@@ -29,6 +29,9 @@ class Instrument:
 		if 'step' in parameters:
 			self.step = parameters["step"]
 
+		if 'midi-instr' in parameters:
+			fluidsynth.midi.set_instrument(self.params["channel"], self.params["midi-instr"])
+
 
 	def play(self, state):
 			
