@@ -8,7 +8,13 @@ reincarnatie = [(0, ["I", "bIIIM7"]),
 		(23, ["Im", "Vm"]),
 		(24, 'R')]
 
-fietsen = [(0, ["I5", "bIII5"]),
+fietsen_intro = [
+	   (0, ["I5", "bIII5"]),
 	   (3, ["IV5", "bIII5"]),
 	   (4, ["I5", "bIII5"]),
-	   (7, ["IV5", "bIII5"])]
+	   (7, ["IV5", "bIII5"]),
+	   (8, 'R')]
+
+fietsen_couplet = [(0, ["I", "IV", "#Vdom7", "V7"]),
+		   (1, 'R')]
+
